@@ -6,7 +6,11 @@
 # llvm-toolchain-snapshot-3.2_3.2repack.orig-lld.tar.bz2
 # llvm-toolchain-snapshot-3.2_3.2repack.orig-lldb.tar.bz2
 # llvm-toolchain-snapshot-3.2_3.2repack.orig-polly.tar.bz2
+# llvm-toolchain-snapshot-3.2_3.2repack.orig-openmp.tar.bz2
+# llvm-toolchain-snapshot-3.2_3.2repack.orig-libcxx.tar.bz2
+# llvm-toolchain-snapshot-3.2_3.2repack.orig-libcxxabi.tar.bz2
 # llvm-toolchain-snapshot-3.2_3.2repack.orig.tar.bz2
+
 set -e
 
 # TODO rest of the options
@@ -14,18 +18,18 @@ set -e
 # To create an rc1 release:
 # sh 4.0/debian/orig-tar.sh RELEASE_40 rc1
 
-SVN_BASE_URL=https://llvm.org/svn/llvm-project/
-MAJOR_VERSION=6.0
-CURRENT_VERSION=6.0.1 # Should be changed to 3.5.1 later
+SVN_BASE_URL=http://llvm.org/svn/llvm-project/
+MAJOR_VERSION=7
+CURRENT_VERSION=7.0.1 # Should be changed to 3.5.1 later
 
 if test -n "$1"; then
-# https://llvm.org/svn/llvm-project/{cfe,llvm,compiler-rt,...}/branches/google/stable/
+# http://llvm.org/svn/llvm-project/{cfe,llvm,compiler-rt,...}/branches/google/stable/
 # For example: sh 4.0/debian/orig-tar.sh release_400
     BRANCH=$1
 fi
 
 if test -n "$1" -a -n "$2"; then
-# https://llvm.org/svn/llvm-project/{cfe,llvm,compiler-rt,...}/tags/RELEASE_34/rc1/
+# http://llvm.org/svn/llvm-project/{cfe,llvm,compiler-rt,...}/tags/RELEASE_34/rc1/
 # For example: sh 4.0/debian/orig-tar.sh RELEASE_401 rc3 4.0.1
     BRANCH=$1
     TAG=$2
@@ -182,6 +186,28 @@ rm -rf $LLDB_TARGET/www/
 tar jcf $FULL_VERSION.orig-lldb.tar.bz2 $LLDB_TARGET
 rm -rf $LLDB_TARGET
 
+# OPENMP
+OPENMP_TARGET=openmp_$VERSION
+checkout_sources openmp $(get_svn_url openmp $BRANCH $TAG) $OPENMP_TARGET "$BRANCH" $REVISION
+rm -rf $OPENMP_TARGET/www/
+tar jcf $FULL_VERSION.orig-openmp.tar.bz2 $OPENMP_TARGET
+rm -rf $OPENMP_TARGET
+
+# LIBCXX
+LIBCXX_TARGET=libcxx_$VERSION
+checkout_sources libcxx $(get_svn_url libcxx $BRANCH $TAG) $LIBCXX_TARGET "$BRANCH" $REVISION
+rm -rf $LIBCXX_TARGET/www/
+tar jcf $FULL_VERSION.orig-libcxx.tar.bz2 $LIBCXX_TARGET
+rm -rf $LIBCXX_TARGET
+
+# LIBCXXABI
+LIBCXXABI_TARGET=libcxxabi_$VERSION
+checkout_sources libcxxabi $(get_svn_url libcxxabi $BRANCH $TAG) $LIBCXXABI_TARGET "$BRANCH" $REVISION
+rm -rf $LIBCXXABI_TARGET/www/
+tar jcf $FULL_VERSION.orig-libcxxabi.tar.bz2 $LIBCXXABI_TARGET
+rm -rf $LIBCXXABI_TARGET
+
+
 PATH_DEBIAN="$(pwd)/$(dirname $0)/../"
 echo "going into $PATH_DEBIAN"
 export DEBFULLNAME="Sylvestre Ledru"
